==> openGion7.0.1.4_dev.zip: uap/webapps/ge/db/ORACLE/sql/install/01_TABLE/GE53S.sql <==
/****************************************************************************/
/* GE53 ( 振分条件ﾏｽﾀ )                                                     */
/*                                                                          */
/* Created : 2018/09/28 16:03:20                                            */
/****************************************************************************/

CREATE TABLE GE53 (
   SYSTEM_ID        VARCHAR2 (  10 )                            NOT NULL            /*  10 ｼｽﾃﾑID       */
 , JOKEN            VARCHAR2 (  20 )                            NOT NULL            /*  20 振分条件     */
 , FGRUN            VARCHAR2 (   1 )                            NOT NULL            /*  30 実行方法     */
 , PRTID            VARCHAR2 (  20 )                                                /*  40 ﾌﾟﾘﾝﾀID      */
 , LANG             VARCHAR2 (   2 )                                                /*  50 言語         */
 , PRGDIR           VARCHAR2 ( 100 )                            NOT NULL            /*  60 実行PGDIR    */
 , PRGFILE          VARCHAR2 (  50 )                            NOT NULL            /*  70 実行PGﾌｧｲﾙ名 */
 , COMMENTS         VARCHAR2 ( 500 )                                                /*  80 ｺﾒﾝﾄ         */
 , DMN_GRP          VARCHAR2 (  20 )        DEFAULT 'DG0000'    NOT NULL            /*  90 ﾃﾞｰﾓﾝｸﾞﾙｰﾌﾟ  */
 , DMN_TIME         NUMBER   (   6 )        DEFAULT 5           NOT NULL            /* 100 ﾃﾞｰﾓﾝ間隔    */
 , RELEASE_NOTES    VARCHAR2 ( 120 )                                                /* 110 ﾘﾘｰｽﾉｰﾄ      */
 , RDC_CODE         VARCHAR2 (  20 )                                                /* 120 設変番号     */
 , OUT_DIR          VARCHAR2 ( 100 )                                                /* 130 出力ﾌｧｲﾙDIR  */
 , OUT_FILE         VARCHAR2 (  50 )                                                /* 140 出力ﾌｧｲﾙ名   */
 , JKN_GRP          VARCHAR2 (  20 )                                                /* 150 条件ｸﾞﾙｰﾌﾟ   */
 , FGJ              VARCHAR2 (   1 )        DEFAULT '1'         NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET            VARCHAR2 (  14 )                                                /* 820 登録日時     */
 , PGSET            VARCHAR2 (  10 )                                                /* 830 作成PG       */
 , PGPSET           VARCHAR2 (  10 )                                                /* 840 作成親PG     */
 , USRSET           VARCHAR2 (  10 )                                                /* 850 作成者       */
 , DYUPD            VARCHAR2 (  14 )                                                /* 860 更新日時     */
 , PGUPD            VARCHAR2 (  10 )                                                /* 870 更新PG       */
 , PGPUPD           VARCHAR2 (  10 )                                                /* 880 更新親PG     */
 , USRUPD           VARCHAR2 (  10 )                                                /* 890 更新者       */
)
TABLESPACE GETBL01
STORAGE( INITIAL 16K );

==> openGion7.3.0.1_dev.zip: uap/webapps/ge/db/ORACLE/sql/install/01_TABLE/GE53S.sql <==
/****************************************************************************/
/* GE53 ( 振分条件ﾏｽﾀ )                                                     */
/*                                                                          */
/* Created : 2020/12/16 08:13:51                                            */
/****************************************************************************/

CREATE TABLE GE53 (
   SYSTEM_ID        VARCHAR2 (  10 )                            NOT NULL            /*  10 ｼｽﾃﾑID       */
 , JOKEN            VARCHAR2 (  20 )                            NOT NULL            /*  20 振分条件     */
 , FGRUN            VARCHAR2 (   1 )                            NOT NULL            /*  30 実行方法     */
 , PRTID            VARCHAR2 (  20 )                                                /*  40 ﾌﾟﾘﾝﾀID      */
 , LANG             VARCHAR2 (   2 )                                                /*  50 言語         */
 , PRGDIR           VARCHAR2 ( 100 )                            NOT NULL            /*  60 実行PGDIR    */
 , PRGFILE          VARCHAR2 (  50 )                            NOT NULL            /*  70 実行PGﾌｧｲﾙ名 */
 , COMMENTS         VARCHAR2 ( 500 )                                                /*  80 ｺﾒﾝﾄ         */
 , DMN_GRP          VARCHAR2 (  20 )        DEFAULT 'DG0000'    NOT NULL            /*  90 ﾃﾞｰﾓﾝｸﾞﾙｰﾌﾟ  */
 , DMN_TIME         NUMBER   (   6 )        DEFAULT 5           NOT NULL            /* 100 ﾃﾞｰﾓﾝ間隔    */
 , RELEASE_NOTES    VARCHAR2 ( 120 )                                                /* 110 ﾘﾘｰｽﾉｰﾄ      */
 , RDC_CODE         VARCHAR2 (  20 )                                                /* 120 設変番号     */
 , OUT_DIR          VARCHAR2 ( 100 )                                                /* 130 出力ﾌｧｲﾙDIR  */
 , OUT_FILE         VARCHAR2 (  50 )                                                /* 140 出力ﾌｧｲﾙ名   */
 , JKN_GRP          VARCHAR2 (  20 )                                                /* 150 条件ｸﾞﾙｰﾌﾟ   */
 , FGJ              VARCHAR2 (   1 )        DEFAULT '1'         NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET            VARCHAR2 (  14 )                                                /* 820 作成日時     */
 , PGSET            VARCHAR2 (  10 )                                                /* 830 作成PG       */
 , PGPSET           VARCHAR2 (  10 )                                                /* 840 作成親PG     */
 , USRSET           VARCHAR2 (  10 )                                                /* 850 作成者       */
 , DYUPD            VARCHAR2 (  14 )                                                /* 860 更新日時     */
 , PGUPD            VARCHAR2 (  10 )                                                /* 870 更新PG       */
 , PGPUPD           VARCHAR2 (  10 )                                                /* 880 更新親PG     */
 , USRUPD           VARCHAR2 (  10 )                                                /* 890 更新者       */
)
TABLESPACE GETBL01
STORAGE( INITIAL 16K );
